% This program produces the pdf pictures of the
% identified set for different values of C and K.

% Set up the workspace to get started
clear;
close all;
clc;

% Set up some population parameters
beta = [1;2];

% Set up the values at which we will evalue this - For K and C 
GridK = [5 9 15];
GridC = [1 0.5 0.1];

% Circle through different values of K and graph Cs in there
for k=1:length(GridK)
    % Set the K value for this loop - Build support
    K = GridK(k); suppz = linspace(-5,5,K); %Z's support
    
    % Iterate through different vlaues of C
    for j = 1:length(GridC)
        % Set parameter values (DGP)
        c = GridC(j);
    
        % Create the upper and lower bounds
        EyLz = [ones(K,1),suppz']*beta-c-0.1*(suppz.^2)';
        EyUz = [ones(K,1),suppz']*beta+c+0.1*(suppz.^2)';
        
        % Set linear inequality constraints up
        A = [-suppz' -ones(K,1); suppz' ones(K,1)];
        FL = [-EyLz; EyUz];
        [dF dt]=size(A);

        % Plot the identified region for these parameter values
        if j == 1
            subplot(1,length(GridK),k);
        end
        theta = sdpvar(dt,1);
        ThetaI = [A*theta<=FL];
        
        % This is manually set to iterate colors for 3 choices of c
        switch j
            case 1                
                plot(ThetaI,[],[0.8 0.8 1]);
                legend(['c = ' num2str(c)]); 
            case 2
                plot(ThetaI,[],[0.5 0.5 1]);
                legend(['c = ' num2str(c)]);
            case 3
                plot(ThetaI,[],[0.2 0.2 1]);
                legend(['c = ' num2str(c)]);
        end
        
        axis([-0.5,2.5,1.2,2.8])
        axis([1.2,2.8,-0.2,2.2])
        title(['Parameter K=' num2str(K)])
        xlabel('\theta_2'); ylabel('\theta_1');
        legend('c = 1', 'c = 0.5', 'c = 0.1'); legend BOXOFF;
    end
end
print -dpdf './figures/MCFig1.pdf'
